function [coordinate, faces, faceCentres, scalar, vectorComponent] = OF_ReadSampleFile_Surfaces()
% This function loads OpenFOAM constant and inperpolated planes extracted
% using the 'sample' utility and converts the plane/planes into a
% triangular mesh format readily recognised by Matlab
%
% Usage: 
% - The user must change the current directory to the time directory of
% interest (within the 'object' i.e. interpolatedPlane of the name given   to the surface itself)
% - ConstantPlane data should be plot using trisuf(faces,x,y,z,pressure).
% - Interpolated planes should be plot using trisurf (faces,x,y,z,pressure, 'facecolor','interp')
% - NOTE: for best results use cellPoint interpolation (cellPointFace takes longer to sample 
%   and no obvious improvement in the quality of the final figure was observed)
%
% Output:
% - coordinate: structure array containing x, y and z coordinates. The
%   data can be accessed using the form coordinate.<axis>, where <axis>
%   can take the values x, y or z.
% - faces: array of size mx3 containing the indices to the vertices 
%   of every triangle. Corresponds to the tri matrix need for the trisurf
%   function.
% - faceCentres: structure array containing x, y and z coordinates for 
%   cell centres. The data can be accessed using the form 
%   faceCentres.<axis> where <axis> can take the values x, y or z.
% - pressure: scalar values for at each coordinate. Used in colormap!
% - velocity: structure array containing velocity component in x, y and z.


% Load faces
 fid = fopen('faces','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('')
 disp('Reading faces')
  
 OF_faces = fscanf(fid,'%d(%d %d %d)', [4 inf])';
 
 fclose(fid);
 
 % Removing first column (number of verticies 
 % e.g. 3 for triangulated surface)
 faces(:,1) = OF_faces(:,2);
 faces(:,2) = OF_faces(:,3); 
 faces(:,3) = OF_faces(:,4);
 % Converting to Matlab/Octave format (e.g. index + 1)
 faces = faces + 1;
 
 clear OF_faces;
 
 % Load face centres
 fid = fopen('faceCentres','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('Reading face centres')
  
 OF_face_centres = fscanf(fid,'(%f %f %f)\n', [3 inf])';
 
 fclose(fid);
 
 %Removing first column (number of verticies 
 % e.g. 3 for triangulated surface)
 faceCentres.x = OF_face_centres(:,1);
 faceCentres.y = OF_face_centres(:,2);
 faceCentres.z = OF_face_centres(:,3);
 
 
 clear OF_face_centres;
 
% Load points
 fid = fopen('points','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('Reading coordinate points')
 points = fscanf(fid,'(%f %f %f)\n', [3 inf])';
 
 fclose(fid);
 
coordinate.x = points(:,1);
coordinate.y = points(:,2);
coordinate.z = points(:,3);

clear points;

%%%%%%%%%%%%%%%%%%%%%%%%%% Load scalars %%%%%%%%%%%%%%%%%%%%%%%%%%


cd scalarField

scalarFiles = dir;

disp('Reading scalars')

for i = 3:(length(scalarFiles)) % 3 start option to ignore directories . & ..
 fid = fopen(scalarFiles(i).name,'rt');
 
  firstLine = fgetl(fid);

  zeroTimeCheck = findstr(firstLine,'{');

%%% Checking whether zero time directory contains data %%%
if isempty(zeroTimeCheck) == 0 
  fclose(fid);
  fid = fopen(scalarFiles(i).name,'rt');
  zeroTimeData = fscanf(fid,'%d{%f}');
  fclose(fid);
  % Generate vector field for time zero
  scalar(i-2).sample = zeros(zeroTimeData(1),1);
  scalar(i-2).sample(:) = zeroTimeData(2);
  scalar(i-2).name   = scalarFiles(i).name;
  
else

  fgetl(fid);
  fgetl(fid);
 
 scalar(i-2).sample = fscanf(fid,'%e\n', [1 inf])';
 scalar(i-2).name   = scalarFiles(i).name;
 
 fclose(fid);
 
end % End zero time data check
end % End loop
 
 cd ..
 
%%%%%%%%%%%%%%%%%%%%%%%%%% Load vectors %%%%%%%%%%%%%%%%%%%%%%%%%%

cd vectorField


 fid = fopen('U','rt');

  disp('Reading vectors')
 
  firstLine = fgetl(fid);
  zeroTimeCheck = findstr(firstLine,'{');

%%% Check whether zero time directory contains data %%%
if isempty(zeroTimeCheck) == 0;
  fclose(fid);
  fid = fopen('U','rt');
  zeroTimeData = fscanf(fid,'%d{(%f %f %f)}');
  fclose(fid);
  % Generate vector field for time zero
  vectorComponent.x = zeros(zeroTimeData(1),1);
  vectorComponent.y = zeros(zeroTimeData(1),1);
  vectorComponent.z = zeros(zeroTimeData(1),1);
  vectorComponent.x(:) = zeroTimeData(2);
  vectorComponent.y(:) = zeroTimeData(3);
  vectorComponent.z(:) = zeroTimeData(4);
  
else
  fgetl(fid);
  fgetl(fid);
 
 OF_vector = fscanf(fid,'(%f %f %f)\n', [3 inf])';

 
 fclose(fid);
 
 vectorComponent.x = OF_vector(:,1);
 vectorComponent.y = OF_vector(:,2);
 vectorComponent.z = OF_vector(:,3);

  clear OF_vector;
end % End zero time data check
 
 cd ..
 
 disp('Load completed successully')
 disp('')
